<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip?lang_cible=fr_tu
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'access_interface_graphique' => 'Retour à l’interface graphique complète',
	'access_mode_texte' => 'Afficher l’interface textuelle simplifiée',
	'admin_debug' => 'debug',
	'admin_modifier_article' => 'Modifier cet article',
	'admin_modifier_auteur' => 'Modifier cet auteur',
	'admin_modifier_breve' => 'Modifier cette brève',
	'admin_modifier_mot' => 'Modifier ce mot-clé',
	'admin_modifier_rubrique' => 'Modifier cette rubrique',
	'admin_recalculer' => 'Recalculer cette page',
	'afficher_calendrier' => 'Afficher le calendrier',
	'afficher_trad' => 'afficher les traductions',
	'alerte_maj_impossible' => '<b>Alerte !</b> La mise à jour de la base SQL vers la version @version@ est impossible, peut-être à cause d’un problème de droit de modification sur la base de données. Contacte ton hébergeur.',
	'alerte_modif_info_concourante' => 'ATTENTION : Cette information a été modifiée par ailleurs. La valeur actuelle est :',
	'analyse_xml' => 'Analyse XML',
	'annuler' => 'Annuler',
	'antispam_champ_vide' => 'Laisse ce champ vide :',
	'articles_recents' => 'Articles les plus récents',
	'attention_champ_mini_nb_caractères' => 'Attention ! @nb@ caractères au minimum',
	'avis_1_erreur_saisie' => 'Il y a 1 erreur dans dans ta saisie, vérifie les informations.',
	'avis_archive_incorrect' => 'le fichier archive n’est pas un fichier SPIP',
	'avis_archive_invalide' => 'le fichier archive n’est pas valide',
	'avis_attention' => 'ATTENTION !',
	'avis_champ_incorrect_type_objet' => 'Nom de champ incorrect @name@ pour objet de type @type@',
	'avis_colonne_inexistante' => 'La colonne @col@ n’existe pas',
	'avis_erreur' => 'Erreur : voir ci-dessous',
	'avis_erreur_connexion' => 'Erreur de connexion',
	'avis_erreur_cookie' => 'problème de cookie',
	'avis_erreur_fonction_contexte' => 'Erreur de programmation. Cette fonction ne doit pas être appelée dans ce contexte.',
	'avis_erreur_mysql' => 'Erreur SQL',
	'avis_erreur_sauvegarde' => 'Erreur dans la sauvegarde (@type@ @id_objet@) !',
	'avis_erreur_visiteur' => 'Problème d’accès à l’espace privé',
	'avis_nb_erreurs_saisie' => 'Il y a @nb@ erreurs dans ta saisie, vérifie les informations.',

	// B
	'barre_a_accent_grave' => 'Insérer un A accent grave majuscule',
	'barre_aide' => 'Utilise les raccourcis typographiques pour enrichir ta mise en page',
	'barre_e_accent_aigu' => 'Insérer un E accent aigu majuscule',
	'barre_eo' => 'Insérer un E dans l’O',
	'barre_eo_maj' => 'Insérer un E dans l’O majuscule',
	'barre_euro' => 'Insérer le symbole ?',
	'barre_gras' => 'Mettre en {{gras}}',
	'barre_guillemets' => 'Entourer de « guillemets français »',
	'barre_guillemets_simples' => 'Entourer de ?guillemets de second niveau ?',
	'barre_intertitre' => 'Transformer en {{{intertitre}}}',
	'barre_italic' => 'Mettre en {italique}',
	'barre_lien' => 'Transformer en [lien hypertexte->http://...]',
	'barre_lien_input' => 'Indiquer l’adresse de ton lien (tu peux indiquer une adresse Web sous la forme http://www.monsite/com ou simplement indiquer le numéro d’un article de ce site.',
	'barre_note' => 'Transformer en [[Note de bas de page]]',
	'barre_paragraphe' => 'Crée un paragraphe',
	'barre_quote' => '<quote>Citer un message</quote>',
	'bouton_changer' => 'Changer',
	'bouton_chercher' => 'Chercher',
	'bouton_choisir' => 'Choisir',
	'bouton_deplacer' => 'Déplacer',
	'bouton_download' => 'Télécharger',
	'bouton_enregistrer' => 'Enregistrer',
	'bouton_radio_desactiver_messagerie_interne' => 'Désactiver la messagerie interne',
	'bouton_radio_envoi_annonces' => 'Envoyer les annonces éditoriales',
	'bouton_radio_non_envoi_annonces' => 'Ne pas envoyer d’annonces',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Ne pas envoyer la liste des nouveautés',
	'bouton_recharger_page' => 'recharger cette page',
	'bouton_telecharger' => 'Télécharger',
	'bouton_upload' => 'Téléverser',
	'bouton_valider' => 'Valider',

	// C
	'cal_apresmidi' => 'après-midi',
	'cal_jour_entier' => 'jour entier',
	'cal_matin' => 'matin',
	'cal_par_jour' => 'calendrier par jour',
	'cal_par_mois' => 'calendrier par mois',
	'cal_par_semaine' => 'calendrier par semaine',
	'choix_couleur_interface' => 'couleur ',
	'choix_interface' => 'choix  de l’interface',
	'colonne' => 'Colonne',
	'confirm_changer_statut' => 'Attention, tu as demandé à changer le statut de cet élément. Souhaites-tu continuer ?',
	'correcte' => 'correcte',

	// D
	'date_aujourdhui' => 'aujourd’hui',
	'date_avant_jc' => 'av. J.C.',
	'date_dans' => 'dans @delai@',
	'date_de_mois_1' => '@j@ @nommois@',
	'date_de_mois_10' => '@j@ @nommois@',
	'date_de_mois_11' => '@j@ @nommois@',
	'date_de_mois_12' => '@j@ @nommois@',
	'date_de_mois_2' => '@j@ @nommois@',
	'date_de_mois_3' => '@j@ @nommois@',
	'date_de_mois_4' => '@j@ @nommois@',
	'date_de_mois_5' => '@j@ @nommois@',
	'date_de_mois_6' => '@j@ @nommois@',
	'date_de_mois_7' => '@j@ @nommois@',
	'date_de_mois_8' => '@j@ @nommois@',
	'date_de_mois_9' => '@j@ @nommois@',
	'date_demain' => 'demain',
	'date_fmt_heures_minutes' => '@h@h@m@min',
	'date_fmt_heures_minutes_court' => '@h@h@m@',
	'date_fmt_jour' => '@nomjour@ @jour@',
	'date_fmt_jour_heure' => '@jour@ à @heure@',
	'date_fmt_jour_heure_debut_fin' => 'le @jour@ de @heure_debut@ à @heure_fin@',
	'date_fmt_jour_heure_debut_fin_abbr' => 'le @dtstart@@jour@ de @heure_debut@@dtabbr@ à @dtstart@@heure_fin@@dtend@',
	'date_fmt_jour_mois' => '@jour@ @nommois@',
	'date_fmt_jour_mois_annee' => '@jour@ @nommois@ @annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour' => '@nomjour@ @date@',
	'date_fmt_nomjour_date' => 'le @nomjour@ @date@',
	'date_fmt_periode' => 'Du @date_debut@ au @date_fin@',
	'date_fmt_periode_abbr' => 'Du @dtart@@date_debut@@dtabbr@ au @dtend@@date_fin@@dtabbr@',
	'date_fmt_periode_from' => 'Du',
	'date_fmt_periode_to' => 'au',
	'date_fmt_saison_annee' => '@saison@ @annee@',
	'date_heures' => 'heures',
	'date_hier' => 'hier',
	'date_il_y_a' => 'il y a @delai@',
	'date_jnum1' => '1er',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'dimanche',
	'date_jour_1_abbr' => 'dim.',
	'date_jour_1_initiale' => 'd.',
	'date_jour_2' => 'lundi',
	'date_jour_2_abbr' => 'lun.',
	'date_jour_2_initiale' => 'l.',
	'date_jour_3' => 'mardi',
	'date_jour_3_abbr' => 'mar.',
	'date_jour_3_initiale' => 'm.',
	'date_jour_4' => 'mercredi',
	'date_jour_4_abbr' => 'mer.',
	'date_jour_4_initiale' => 'm.',
	'date_jour_5' => 'jeudi',
	'date_jour_5_abbr' => 'jeu.',
	'date_jour_5_initiale' => 'j.',
	'date_jour_6' => 'vendredi',
	'date_jour_6_abbr' => 'ven.',
	'date_jour_6_initiale' => 'v.',
	'date_jour_7' => 'samedi',
	'date_jour_7_abbr' => 'sam.',
	'date_jour_7_initiale' => 's.',
	'date_jours' => 'jours',
	'date_minutes' => 'minutes',
	'date_mois' => 'mois',
	'date_mois_1' => 'janvier',
	'date_mois_10' => 'octobre',
	'date_mois_10_abbr' => 'oct.',
	'date_mois_11' => 'novembre',
	'date_mois_11_abbr' => 'nov.',
	'date_mois_12' => 'décembre',
	'date_mois_12_abbr' => 'déc.',
	'date_mois_1_abbr' => 'janv.',
	'date_mois_2' => 'février',
	'date_mois_2_abbr' => 'févr.',
	'date_mois_3' => 'mars',
	'date_mois_3_abbr' => 'mars',
	'date_mois_4' => 'avril',
	'date_mois_4_abbr' => 'avr.',
	'date_mois_5' => 'mai',
	'date_mois_5_abbr' => 'mai',
	'date_mois_6' => 'juin',
	'date_mois_6_abbr' => 'juin',
	'date_mois_7' => 'juillet',
	'date_mois_7_abbr' => 'juil.',
	'date_mois_8' => 'août',
	'date_mois_8_abbr' => 'août',
	'date_mois_9' => 'septembre',
	'date_mois_9_abbr' => 'sept.',
	'date_saison_1' => 'hiver',
	'date_saison_2' => 'printemps',
	'date_saison_3' => 'été',
	'date_saison_4' => 'automne',
	'date_secondes' => 'secondes',
	'date_semaines' => 'semaines',
	'date_un_mois' => 'mois',
	'date_une_heure' => 'heure',
	'date_une_minute' => 'minute',
	'date_une_seconde' => 'seconde',
	'date_une_semaine' => 'semaine',
	'dirs_commencer' => ' afin de commencer réellement l’installation',
	'dirs_preliminaire' => 'Préliminaire : <b>Régler les droits d’accès</b>',
	'dirs_probleme_droits' => 'Problème de droits d’accès',
	'dirs_repertoires_absents' => '<p><b>Les répertoires suivants n’ont pas été trouvés :</b></p><ul>@bad_dirs@.</ul>
  <p>Il est probable que cela soit dû à un problème de mauvaise mise en majuscules ou minuscules.
  Vérifie que les minuscules et majuscules de ces répertoires concordent bien avec ce qui est affiché
  ci-dessus ; si ce n’est pas le cas, renomme les répertoires avec ton logiciel FTP de façon à corriger l’erreur.</p>
  <p>Une fois cette manipulation effectuée, tu pourras ',
	'dirs_repertoires_suivants' => '<p><b>Les répertoires suivants ne sont pas accessibles en écriture :</b></p> <ul>@bad_dirs@</ul>
  <p>Pour y remédier, utilise ton client FTP afin de régler les droits d’accès de chacun
  de ces répertoires. La procédure est expliquée en détail dans le guide d’installation.</p>
  <p>Une fois cette manipulation effectuée, tu pourras ',
	'double_occurrence' => 'Double occurrence de @balise@',

	// E
	'en_cours' => 'en cours',
	'envoi_via_le_site' => 'Envoi via le site',
	'erreur' => 'Erreur',
	'erreur_balise_non_fermee' => 'dernière balise non refermée :',
	'erreur_technique_ajaxform' => 'Ooops. Une erreur innatendue a empêché de soumettre le formulaire. Tu peux essayer à nouveau.',
	'erreur_technique_enregistrement_champs' => 'Une erreur technique a empêché l’enregistrement correct du champ @champs@.',
	'erreur_technique_enregistrement_impossible' => 'Une erreur technique a empêché l’enregistrement.',
	'erreur_texte' => 'erreur(s)',
	'etape' => 'Étape',

	// F
	'fichier_introuvable' => 'Fichier @fichier@ introuvable', # MODIF
	'form_auteur_confirmation' => 'Confirme ton adresse email',
	'form_auteur_email_modifie' => 'Ton adresse email a été modifiée.',
	'form_auteur_envoi_mail_confirmation' => 'Un courrier électronique de confirmation vient d’être envoyé à @email@. Visite l’adresse Web mentionnée dans ce courrier pour valider ton adresse mail.',
	'form_auteur_mail_confirmation' => 'Salut,

Tu as demandé à changer ton adresse email.
Pour confirmer ta nouvelle adresse, il suffit de te connecter à
l’adresse ci-dessous (dans le cas contraire, ta demande
sera ignorée) :

    @url@
',
	'form_deja_inscrit' => 'Tu es déjà inscrit.',
	'form_email_non_valide' => 'Ton adresse email n’est pas valide.',
	'form_forum_access_refuse' => 'Tu n’as plus accès à ce site.',
	'form_forum_bonjour' => 'Salut @nom@,',
	'form_forum_confirmer_email' => 'Pour confirmer ton adresse email, va à cette adresse : @url_confirm@',
	'form_forum_email_deja_enregistre' => 'Cette adresse email est déjà enregistrée, tu peux donc utiliser ton mot de passe habituel.',
	'form_forum_identifiant_mail' => 'Ton nouvel identifiant vient de t’être envoyé par email.',
	'form_forum_identifiants' => 'Identifiants personnels',
	'form_forum_indiquer_nom_email' => 'Indique ici ton nom et ton adresse email. Ton identifiant personnel te parviendra rapidement, par courrier électronique.',
	'form_forum_login' => 'login :',
	'form_forum_message_auto' => '(ceci est un message automatique)',
	'form_forum_pass' => 'mot de passe :',
	'form_forum_probleme_mail' => 'Problème de mail : l’identifiant ne peut pas être envoyé.',
	'form_forum_voici1' => 'Voici tes identifiants pour pouvoir participer à la vie du site "@nom_site_spip@" (@adresse_site@) :',
	'form_forum_voici2' => 'Voici tes identifiants pour proposer des articles sur
le site "@nom_site_spip@" (@adresse_login@) :',
	'form_indiquer_email' => 'Indique ton adresse email.',
	'form_indiquer_nom' => 'Indique ton nom.',
	'form_indiquer_nom_site' => 'Indique le nom de ton site.',
	'form_pet_deja_enregistre' => 'Ce site est déjà enregistré',
	'form_pet_signature_pasprise' => 'Ta signature n’est pas prise en compte.',
	'form_prop_confirmer_envoi' => 'Confirmer l’envoi',
	'form_prop_description' => 'Description/commentaire',
	'form_prop_enregistre' => 'Ta proposition est enregistrée, elle apparaîtra en ligne après validation par les responsables de ce site.',
	'form_prop_envoyer' => 'Envoyer un message',
	'form_prop_indiquer_email' => 'Indiquer une adresse email valide',
	'form_prop_indiquer_nom_site' => 'Indiquer le nom du site.',
	'form_prop_indiquer_sujet' => 'Indiquer un sujet',
	'form_prop_message_envoye' => 'Message envoyé',
	'form_prop_non_enregistre' => 'Ta proposition n’a pas été enregistrée.',
	'form_prop_sujet' => 'Sujet',
	'form_prop_url_site' => 'Adresse URL du site',
	'format_date_attendu' => 'Saisir une date au format jj/mm/aaaa.',
	'format_date_incorrecte' => 'La date ou son format est incorrect',
	'format_heure_attendu' => 'Saisir une heure au format hh:mm.',
	'format_heure_incorrecte' => 'L’heure ou son format est incorrect',
	'forum_non_inscrit' => 'Tu n’es pas inscrit, ou l’adresse ou le mot de passe sont erronés.',
	'forum_par_auteur' => 'par @auteur@',
	'forum_titre_erreur' => 'Erreur...',

	// I
	'ical_texte_rss_articles' => 'Le fichier « backend » des articles de ce site se trouve à l’adresse :',
	'ical_texte_rss_articles2' => 'Tu peux également obtenir des fichiers « backend » pour les articles de chaque rubrique du site :',
	'ical_texte_rss_breves' => 'Il existe de plus un fichier contenant les brèves du site. En précisant un numéro de rubrique, tu obtiendras uniquement les brèves de cette rubrique.',
	'icone_a_suivre' => 'À suivre',
	'icone_admin_site' => 'Administration du site',
	'icone_agenda' => 'Agenda',
	'icone_aide_ligne' => 'Aide',
	'icone_articles' => 'Articles',
	'icone_auteurs' => 'Auteurs',
	'icone_brouteur' => 'Navigation rapide',
	'icone_configuration_site' => 'Configuration',
	'icone_configurer_site' => 'Configurer ton site',
	'icone_creer_nouvel_auteur' => 'Créer un nouvel auteur',
	'icone_creer_rubrique' => 'Créer une rubrique',
	'icone_creer_sous_rubrique' => 'Créer une sous-rubrique',
	'icone_deconnecter' => 'Se déconnecter',
	'icone_discussions' => 'Discussions',
	'icone_doc_rubrique' => 'Documents des rubriques',
	'icone_ecrire_article' => 'Écrire un nouvel article',
	'icone_edition_site' => 'Édition',
	'icone_gestion_langues' => 'Gestion des langues',
	'icone_informations_personnelles' => 'Informations personnelles',
	'icone_interface_complet' => 'interface complète',
	'icone_interface_simple' => 'Interface simplifiée',
	'icone_maintenance_site' => 'Maintenance du site',
	'icone_messagerie_personnelle' => 'Messagerie personnelle',
	'icone_repartition_debut' => 'Afficher la répartition depuis le début',
	'icone_rubriques' => 'Rubriques',
	'icone_sauver_site' => 'Sauvegarde du site',
	'icone_site_entier' => 'Tout le site',
	'icone_sites_references' => 'Sites référencés',
	'icone_statistiques' => 'Statistiques du site',
	'icone_suivi_activite' => 'Suivre la vie du site',
	'icone_suivi_actualite' => 'Évolution du site',
	'icone_suivi_pettions' => 'Suivre/gérer les pétitions',
	'icone_suivi_revisions' => 'Modifications des articles',
	'icone_supprimer_document' => 'Supprimer ce document',
	'icone_supprimer_image' => 'Supprimer cette image',
	'icone_tous_articles' => 'Tous tes articles',
	'icone_tous_auteur' => 'Tous les auteurs',
	'icone_tous_visiteur' => 'Tous les visiteurs',
	'icone_visiter_site' => 'Voir le site public',
	'icone_voir_en_ligne' => 'Voir en ligne',
	'img_indisponible' => 'image indisponible',
	'impossible' => 'impossible',
	'info_a_suivre' => 'À SUIVRE »',
	'info_acces_interdit' => 'Accès interdit',
	'info_acces_refuse' => 'Accès refusé',
	'info_action' => 'Action : @action@',
	'info_administrer_rubriques' => 'Tu peux administrer cette rubrique et ses sous-rubriques',
	'info_adresse_non_indiquee' => 'Tu n’as pas indiqué d’adresse à tester !',
	'info_aide' => 'AIDE :',
	'info_ajouter_mot' => 'Ajouter ce mot',
	'info_annonce' => 'ANNONCE',
	'info_annonces_generales' => 'Annonces générales :',
	'info_article_propose' => 'Article proposé',
	'info_article_publie' => 'Article publié',
	'info_article_redaction' => 'Article en cours de rédaction',
	'info_article_refuse' => 'Article refusé',
	'info_article_supprime' => 'Article supprimé',
	'info_articles' => 'Articles',
	'info_articles_a_valider' => 'Les articles à valider',
	'info_articles_nb' => '@nb@ articles',
	'info_articles_proposes' => 'Articles proposés',
	'info_articles_un' => '1 article',
	'info_auteurs_nombre' => 'auteur(s) :',
	'info_authentification_ftp' => 'Authentification (par FTP).',
	'info_breves_2' => 'brèves',
	'info_breves_nb' => '@nb@ brèves',
	'info_breves_un' => '1 brève',
	'info_connexion_refusee' => 'Connexion refusée',
	'info_contact_developpeur' => 'Contacte un développeur.',
	'info_contenance' => 'Ce site contient :',
	'info_contribution' => 'contributions',
	'info_copyright' => '@spip@ est un logiciel libre distribué @lien_gpl@.',
	'info_copyright_doc' => 'Pour plus d’informations, voir le site <a href="@spipnet@">@spipnet_affiche@</a>.',
	'info_copyright_gpl' => 'sous licence GPL',
	'info_cours_edition' => 'En cours de modification',
	'info_creer_repertoire' => 'Crée un fichier ou un répertoire nommé :',
	'info_creer_repertoire_2' => 'à l’intérieur du sous-répertoire <b>@repertoire@</b>, puis :',
	'info_creer_vignette' => 'création automatique de la vignette',
	'info_creerdansrubrique_non_autorise' => 'Tu n’as pas de droits suffisants pour créer un contenu dans cette rubrique',
	'info_deplier' => 'Déplier',
	'info_descriptif_nombre' => 'descriptif(s) :',
	'info_description' => 'Description :',
	'info_description_2' => 'Description :',
	'info_dimension' => 'Dimensions :',
	'info_documents_nb' => '@nb@ documents',
	'info_documents_un' => '1 document',
	'info_ecire_message_prive' => 'Écrire un message privé',
	'info_email_invalide' => 'Adresse email invalide.',
	'info_en_cours_validation' => 'Tes articles en cours de rédaction',
	'info_en_ligne' => 'Actuellement en ligne :',
	'info_envoyer_message_prive' => 'Envoyer un message privé à cet auteur',
	'info_erreur_requete' => 'Erreur dans la requête :',
	'info_erreur_squelette2' => 'Aucun squelette <b>@fichier@</b> n’est disponible...',
	'info_erreur_systeme' => 'Erreur système (errno @errsys@)',
	'info_erreur_systeme2' => 'Le disque dur est peut-être plein, ou la base de données endommagée.<br />
<span style="color:red;">Essaie de <a href=\'@script@\'>réparer la base</a>, ou contacte ton hébergeur.</span>',
	'info_fini' => 'C’est fini !',
	'info_format_image' => 'Formats d’images pouvant être utilisées pour créer des vignettes : @gd_formats@.',
	'info_format_non_defini' => 'format non défini',
	'info_grand_ecran' => 'Grand écran',
	'info_image_aide' => 'AIDE',
	'info_image_process_titre' => 'Comment faire de nouveaux signets',
	'info_impossible_lire_page' => '<b>Erreur !</b> Impossible de lire la page <tt><html>@test_proxy@</html></tt> à travers le proxy ',
	'info_installation_systeme_publication' => 'Installation du système de publication...',
	'info_installer_documents' => 'Tu peux installer automatiquement tous les documents contenus dans le dossier @upload@.',
	'info_installer_ftp' => 'En tant qu’administrateur, tu peux installer (par FTP) des fichiers dans le dossier @upload@ pour ensuite les sélectionner directement ici.',
	'info_installer_images' => 'Tu peux installer des images aux formats JPEG, GIF et PNG.',
	'info_installer_images_dossier' => 'Installer des images dans le dossier @upload@ pour pouvoir les sélectionner ici.',
	'info_interface_complete' => 'interface complète',
	'info_interface_simple' => 'Interface simplifiée',
	'info_joindre_document_article' => 'Tu peux joindre à cet article des documents de type',
	'info_joindre_document_rubrique' => 'Tu peux ajouter dans cette rubrique des documents de type',
	'info_joindre_documents_article' => 'Tu peux joindre à ton article des documents de type :',
	'info_l_article' => 'l’article',
	'info_la_breve' => 'la brève',
	'info_la_rubrique' => 'la rubrique',
	'info_langue_principale' => 'Langue principale du site',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ pixels',
	'info_les_auteurs_1' => 'par @les_auteurs@',
	'info_logo_format_interdit' => 'Seuls les logos aux formats @formats@ sont autorisés.',
	'info_logo_max_poids' => 'Les logos doivent obligatoirement faire moins de @maxi@ (ce fichier fait @actuel@).',
	'info_mail_fournisseur' => 'toi@fournisseur.com',
	'info_message_2' => 'MESSAGE',
	'info_message_supprime' => 'MESSAGE SUPPRIMÉ',
	'info_messages_nb' => '@nb@ messages',
	'info_messages_un' => '1 message',
	'info_mise_en_ligne' => 'Date de mise en ligne :',
	'info_modification_parametres_securite' => 'modifications des paramètres de sécurité',
	'info_mois_courant' => 'Dans le courant du mois :',
	'info_mot_cle_ajoute' => 'Le mot-clé suivant a été ajouté à',
	'info_multi_herit' => 'Langue par défaut',
	'info_multi_langues_soulignees' => 'Les <u>langues soulignées</u> bénéficient d’une traduction totale ou partielle des textes de l’interface. Si tu sélectionnes ces langues, de nombreux éléments du site public (dates, formulaires) seront automatiquement traduits. Pour les langues non soulignées, ces éléments apparaîtront dans la langue principale du site.',
	'info_multilinguisme' => 'Multilinguisme',
	'info_nom_non_utilisateurs_connectes' => 'Ton nom n’apparaît pas dans la liste des utilisateurs connectés.',
	'info_nom_utilisateurs_connectes' => 'Ton nom apparaît dans la liste des utilisateurs connectés.',
	'info_nombre_en_ligne' => 'Actuellement en ligne :',
	'info_non_resultat' => 'Aucun résultat pour "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'Tu n’utilise pas la messagerie interne de ce site.',
	'info_nouveau_message' => 'TU AS UN NOUVEAU MESSAGE',
	'info_nouveaux_messages' => 'TU AS @total_messages@ NOUVEAUX MESSAGES',
	'info_numero_abbreviation' => 'N° ',
	'info_obligatoire' => 'Cette information est obligatoire',
	'info_page_actuelle' => 'Page actuelle',
	'info_pense_bete' => 'PENSE-BÊTE',
	'info_petit_ecran' => 'Petit écran',
	'info_petition_close' => 'Pétition close',
	'info_pixels' => 'pixels',
	'info_plusieurs_mots_trouves' => 'Plusieurs mots-clés trouvés pour "@cherche_mot@" :',
	'info_portfolio_automatique' => 'Portfolio automatique :',
	'info_premier_resultat' => '[@debut_limit@ premiers résultats sur @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ premiers résultats sur @total@]',
	'info_propose_1' => '[@nom_site_spip@] Propose : @titre@',
	'info_propose_2' => 'Article proposé
---------------',
	'info_propose_3' => 'L’article "@titre@" est proposé à la publication.',
	'info_propose_4' => 'Tu es invité à venir le consulter et à donner ton opinion',
	'info_propose_5' => 'dans le forum qui lui est attaché. Il est disponible à l’adresse :',
	'info_publie_01' => 'L’article "@titre@" a été validé par @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] PUBLIE : @titre@',
	'info_publie_2' => 'Article publié
--------------',
	'info_rechercher' => 'Rechercher',
	'info_rechercher_02' => 'Rechercher :',
	'info_remplacer_vignette' => 'Remplacer la vignette par défaut par un logo personnalisé :',
	'info_rubriques_nb' => '@nb@ rubriques',
	'info_rubriques_un' => '1 rubrique',
	'info_sans_titre_2' => 'sans titre',
	'info_selectionner_fichier' => 'Tu peux sélectionner un fichier du dossier @upload@',
	'info_selectionner_fichier_2' => 'Sélectionner un fichier :',
	'info_sites_nb' => '@nb@ sites',
	'info_sites_un' => '1 site',
	'info_supprimer_vignette' => 'supprimer la vignette',
	'info_symbole_bleu' => 'Le symbole <b>bleu</b> indique un <b>pense-bête</b> : c’est-à-dire un message à ton usage personnel.',
	'info_symbole_jaune' => 'Le symbole <b>jaune</b> indique une <b>annonce à tous les rédacteurs</b> : modifiable par tous les administrateurs, et visible par tous les rédacteurs.',
	'info_symbole_vert' => 'Le symbole <b>vert</b> indique les <b>messages échangés avec d’autres utilisateurs</b> du site.',
	'info_telecharger_nouveau_logo' => 'Télécharger un nouveau logo :',
	'info_telecharger_ordinateur' => 'Télécharger depuis ton ordinateur :',
	'info_tous_resultats_enregistres' => '[tous les résultats sont enregistrés]',
	'info_tout_afficher' => 'Tout afficher',
	'info_travaux_texte' => 'Ce site n’est pas encore configuré. Reviens plus tard...',
	'info_travaux_titre' => 'Site en travaux',
	'info_trop_resultat' => 'Trop de résultats pour "@cherche_mot@" ; affine la recherche.',
	'info_utilisation_messagerie_interne' => 'Tu utilises la messagerie interne de ce site.',
	'info_valider_lien' => 'valider ce lien',
	'info_verifier_image' => ', vérifie que tes images ont été transférées correctement.',
	'info_vignette_defaut' => 'Vignette par défaut',
	'info_vignette_personnalisee' => 'Vignette personnalisée',
	'info_visite' => 'visite :',
	'info_vos_rendez_vous' => 'Tes rendez-vous à venir',
	'infos_vos_pense_bete' => 'Tes pense-bêtes',

	// L
	'label_ajout_id_rapide' => 'Ajout rapide',
	'label_poids_fichier' => 'Taille',
	'label_ponctuer' => '@label@ :',
	'lien_afficher_icones_seuls' => 'Afficher uniquement les icones',
	'lien_afficher_texte_icones' => 'Afficher les icones et le texte',
	'lien_afficher_texte_seul' => 'Afficher uniquement le texte',
	'lien_aller_a_la_derniere_page' => 'Aller à la dernière page',
	'lien_aller_a_la_page_nb' => 'Aller à la page @nb@',
	'lien_aller_a_la_page_precedente' => 'Aller à la page précédente',
	'lien_aller_a_la_page_suivante' => 'Aller à la page suivante',
	'lien_aller_a_la_premiere_page' => 'Aller à la première page',
	'lien_liberer' => 'libérer',
	'lien_liberer_tous' => 'Tout libérer',
	'lien_nouvea_pense_bete' => 'NOUVEAU PENSE-BÊTE',
	'lien_nouveau_message' => 'NOUVEAU MESSAGE',
	'lien_nouvelle_annonce' => 'NOUVELLE ANNONCE',
	'lien_petitions' => 'PÉTITION',
	'lien_popularite' => 'popularité : @popularite@%',
	'lien_racine_site' => 'RACINE DU SITE',
	'lien_reessayer' => 'réessayer',
	'lien_repondre_message' => 'Répondre à ce message',
	'lien_supprimer' => 'supprimer',
	'lien_tout_afficher' => 'Tout afficher',
	'lien_visite_site' => 'visiter ce site',
	'lien_visites' => '@visites@ visites',
	'lien_voir_auteur' => 'Voir cet auteur',
	'ligne' => 'Ligne',
	'login' => 'Connexion',
	'login_acces_prive' => 'accès à l’espace privé',
	'login_autre_identifiant' => 'se connecter sous un autre identifiant',
	'login_cookie_accepte' => 'Régle ton navigateur pour qu’il les accepte (au moins pour ce site).',
	'login_cookie_oblige' => 'Pour t’identifier de façon sûre sur ce site, tu dois accepter les cookies.',
	'login_deconnexion_ok' => 'Déconnexion effectuée.',
	'login_erreur_pass' => 'Erreur de mot de passe.',
	'login_espace_prive' => 'espace privé',
	'login_identifiant_inconnu' => 'L’identifiant « @login@ » est inconnu.',
	'login_login' => 'Login :',
	'login_login2' => 'Login ou adresse email@circ@ :',
	'login_login_pass_incorrect' => '(Login ou mot de passe incorrect.)',
	'login_motpasseoublie' => 'mot de passe oublié ?',
	'login_non_securise' => 'Attention, ce formulaire n’est pas sécurisé.
			Si tu ne veux pas que ton mot de passe puisse être
			intercepté sur le réseau, active Javascript
			dans ton navigateur et',
	'login_nouvelle_tentative' => 'Nouvelle tentative',
	'login_par_ici' => 'Tu es enregistré... par ici...',
	'login_pass2' => 'Mot de passe :',
	'login_preferez_refuser' => '<b>Si tu préfére refuser les cookies</b>, une autre méthode de connexion (moins sécurisée) est à ta disposition :',
	'login_recharger' => 'recharger cette page',
	'login_rester_identifie' => 'Se souvenir de moi',
	'login_retour_public' => 'Retour au site public',
	'login_retour_site' => 'Retour au site public',
	'login_retoursitepublic' => 'retour au site public',
	'login_sans_cookie' => 'Identification sans cookie',
	'login_securise' => 'Login sécurisé',
	'login_sinscrire' => 's’inscrire',
	'login_test_navigateur' => 'test navigateur/reconnexion',
	'login_verifiez_navigateur' => '(Vérifie toutefois que ton navigateur n’a pas mémorisé ton mot de passe...)',

	// M
	'masquer_colonne' => 'Masquer cette colonne',
	'masquer_trad' => 'masquer les traductions',
	'message_nouveaux_identifiants_echec' => 'Impossible de générer de nouveaux identifiants.',
	'message_nouveaux_identifiants_echec_envoi' => 'Les nouveaux identifiants de connexion n’ont pas pu être envoyés.',
	'message_nouveaux_identifiants_ok' => 'Les nouveaux identifiants de connexion ont été envoyés à @email@.',
	'module_fichiers_langues' => 'Fichiers de langue',

	// N
	'navigateur_pas_redirige' => 'Si votre navigateur n’est pas redirigé, cliquez ici pour continuer.',
	'numero' => 'Numéro',

	// O
	'occurence' => 'Occurence',
	'onglet_affacer_base' => 'Effacer la base',
	'onglet_auteur' => 'L’auteur',
	'onglet_contenu_site' => 'Contenu du site',
	'onglet_evolution_visite_mod' => 'Évolution',
	'onglet_fonctions_avances' => 'Fonctions avancées',
	'onglet_informations_personnelles' => 'Informations personnelles',
	'onglet_interactivite' => 'Interactivité',
	'onglet_messagerie' => 'Messagerie',
	'onglet_repartition_rubrique' => 'Répartition par rubriques',
	'onglet_save_restaur_base' => 'Sauvegarder/restaurer la base',
	'onglet_vider_cache' => 'Vider le cache',

	// P
	'pass_choix_pass' => 'Choisis ton nouveau mot de passe :',
	'pass_erreur' => 'Erreur',
	'pass_erreur_acces_refuse' => '<b>Erreur :</b> tu n’as plus accès à ce site.',
	'pass_erreur_code_inconnu' => '<b>Erreur :</b> ce code ne correspond à aucun des visiteurs ayant accès à ce site.',
	'pass_erreur_non_enregistre' => '<b>Erreur :</b> l’adresse <tt>@email_oubli@</tt> n’est pas enregistrée sur ce site.',
	'pass_erreur_non_valide' => '<b>Erreur :</b> cet email <tt>@email_oubli@</tt> n’est pas valide !',
	'pass_erreur_probleme_technique' => '<b>Erreur :</b> à cause d’un problème technique, l’email ne peut pas être envoyé.',
	'pass_espace_prive_bla' => 'L’espace privé de ce site est ouvert aux
		visiteurs, après inscription. Une fois enregistré,
		tu pourras consulter les articles en cours de rédaction,
		proposer des articles et participer à tous les forums.',
	'pass_forum_bla' => 'Tu as demandé à intervenir sur un forum
		réservé aux visiteurs enregistrés.',
	'pass_indiquez_cidessous' => 'Indique ci-dessous l’adresse email sous laquelle tu
			t’es précédemment enregistré. Tu
			recevras un email t’indiquant la marche à suivre pour
			récupérer ton accès.',
	'pass_mail_passcookie' => '(ceci est un message automatique)
Pour retrouver ton accès au site
@nom_site_spip@ (@adresse_site@)
Rends toi à l’adresse suivante :

    @sendcookie@

Tu pourras alors entrer un nouveau mot de passe
et te reconnecter au site.

',
	'pass_mot_oublie' => 'Mot de passe oublié',
	'pass_nouveau_enregistre' => 'Ton nouveau mot de passe a été enregistré.',
	'pass_nouveau_pass' => 'Nouveau mot de passe',
	'pass_ok' => 'OK',
	'pass_oubli_mot' => 'Oubli du mot de passe',
	'pass_procedure_changer' => 'Pour changer ton mot de passe, merci d’indiquer l’adresse email associée à ton compte.',
	'pass_quitter_fenetre' => 'Quitter cette fenêtre',
	'pass_rappel_login' => 'Rappel : ton identifiant (login) est « @login@ ».',
	'pass_recevoir_mail' => 'Un lien de réinitialisation de ton mot de passe t’a été envoyé sur ton adresse email (si celle-ci est valide).',
	'pass_retour_public' => 'Retour sur le site public',
	'pass_rien_a_faire_ici' => 'Rien à faire ici.',
	'pass_vousinscrire' => 'T’inscrire sur ce site',
	'precedent' => 'précédent',
	'previsualisation' => 'Prévisualisation',
	'previsualiser' => 'Prévisualiser',

	// R
	'retour' => 'Retour',

	// S
	'spip_conforme_dtd' => 'SPIP considère ce document comme conforme à son DOCTYPE :',
	'squelette' => 'squelette',
	'squelette_inclus_ligne' => 'squelette inclus, ligne',
	'squelette_ligne' => 'squelette, ligne',
	'stats_visites_et_popularite' => '@visites@ visites ; popularité : @popularite@',
	'suivant' => 'suivant',

	// T
	'taille_go' => '@taille@ Go',
	'taille_ko' => '@taille@ ko',
	'taille_mo' => '@taille@ Mo',
	'taille_octets' => '@taille@ octets',
	'texte_actualite_site_1' => 'Quand tu seras familiarisé(e) avec l’interface, tu pourras cliquer sur « ',
	'texte_actualite_site_2' => 'interface complète',
	'texte_actualite_site_3' => ' » pour ouvrir plus de possibilités.',
	'texte_creation_automatique_vignette' => 'La création automatique de vignettes de prévisualisation est activée sur ce site. Si tu installe à partir de ce formulaire des images au(x) format(s) @gd_formats@, elles seront accompagnées d’une vignette d’une taille maximale de @taille_preview@ pixels.',
	'texte_documents_associes' => 'Les documents suivants sont associés à l’article,
				mais ils n’y ont pas été directement
				insérés. Selon la mise en page du site public,
				ils pourront apparaître sous forme de documents joints.',
	'texte_erreur_mise_niveau_base' => 'Erreur de base de données lors de la mise à niveau.
  L’image <b>@fichier@</b> n’est pas passée (article @id_article@).
  Note bien cette référence, réessaye la mise à
  niveau, et enfin vérifie que les images apparaissent
  toujours dans les articles.',
	'texte_erreur_visiteur' => 'Tu as tenté d’accéder à l’espace privé avec un login qui ne le permet pas.',
	'texte_inc_auth_1' => 'Tu es identifié sous le
  login <b>@auth_login@</b>, mais celui-ci n’existe pas/plus dans la base.
  Essaye de te',
	'texte_inc_auth_2' => 'reconnecter',
	'texte_inc_auth_3' => ', après avoir éventuellement quitté puis
		redémarré ton navigateur.',
	'texte_inc_config' => 'Les modifications effectuées dans ces pages influent notablement sur le
 fonctionnement de ton site. Nous te recommandons de ne pas y intervenir tant que tu n’es pas
 familier du fonctionnement du système SPIP. <br /><br /><b>Plus
 généralement, il est fortement conseillé
 de laisser la charge de ces pages au webmestre principal de ton site.</b>',
	'texte_inc_meta_1' => 'Le système a rencontré une erreur lors de l’écriture du fichier <code>@fichier@</code>. En tant qu’administrateur du site,',
	'texte_inc_meta_2' => 'vérifie les droits d’ecriture',
	'texte_inc_meta_3' => 'sur le répertoire <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'en cours de rédaction',
	'texte_statut_poubelle' => 'à la poubelle',
	'texte_statut_propose_evaluation' => 'proposé à l’évaluation',
	'texte_statut_publie' => 'publié en ligne',
	'texte_statut_refuse' => 'refusé',
	'titre_ajouter_mot_cle' => 'AJOUTER UN MOT-CLÉ :',
	'titre_cadre_raccourcis' => 'RACCOURCIS :',
	'titre_changer_couleur_interface' => 'Changer la couleur de l’interface',
	'titre_image_admin_article' => 'Tu peux administrer cet article',
	'titre_image_administrateur' => 'Administrateur',
	'titre_image_aide' => 'De l’aide sur cet élément',
	'titre_image_auteur_supprime' => 'Auteur supprimé',
	'titre_image_redacteur' => 'Rédacteur sans accès',
	'titre_image_redacteur_02' => 'Rédacteur',
	'titre_image_selecteur' => 'Afficher la liste',
	'titre_image_visiteur' => 'Visiteur',
	'titre_joindre_document' => 'JOINDRE UN DOCUMENT',
	'titre_mots_cles' => 'MOTS-CLÉS',
	'titre_probleme_technique' => 'Attention : un problème technique (serveur SQL) empêche l’accès à cette partie du site. Merci de ta compréhension.',
	'titre_publier_document' => 'PUBLIER UN DOCUMENT DANS CETTE RUBRIQUE',
	'titre_signatures_attente' => 'Signatures en attente de validation',
	'titre_signatures_confirmees' => 'Signatures confirmées',
	'titre_statistiques' => 'Statistiques du site',
	'titre_titre_document' => 'Titre du document :',
	'todo' => 'à venir',
	'trad_definir_reference' => 'Choisir "@titre@" comme référence des traductions',
	'trad_reference' => '(référence des traductions)',

	// U
	'upload_limit' => 'Ce fichier est trop gros pour le serveur ; la taille maximum autorisée en <i>upload</i> est de @max@.',

	// Z
	'zbug_balise_b_aval' => ' : balise B en aval',
	'zbug_balise_inexistante' => 'Balise @balise@ mal déclarée pour @from@',
	'zbug_balise_sans_argument' => 'Argument manquant dans la balise @balise@',
	'zbug_boucle' => 'boucle',
	'zbug_boucle_recursive_undef' => 'boucle récursive non définie',
	'zbug_calcul' => 'calcul',
	'zbug_champ_hors_boucle' => 'Champ @champ@ hors boucle',
	'zbug_champ_hors_critere' => 'Champ @champ@ hors critère @critere@',
	'zbug_champ_hors_motif' => 'Champ @champ@ hors d’un contexte @motif@',
	'zbug_code' => 'code',
	'zbug_critere_inconnu' => 'critère inconnu @critere@',
	'zbug_critere_sur_table_sans_cle_primaire' => '{@critere@} sur une table sans clef primaire atomique',
	'zbug_distant_interdit' => 'externe interdit',
	'zbug_doublon_table_sans_cle_primaire' => 'doublons sur une table sans clef primaire atomique',
	'zbug_doublon_table_sans_index' => 'doublons sur une table sans index',
	'zbug_erreur_boucle_double' => 'BOUCLE@id@ : double définition',
	'zbug_erreur_boucle_fermant' => 'BOUCLE@id@ : tag fermant manquant',
	'zbug_erreur_boucle_syntaxe' => 'Syntaxe boucle incorrecte',
	'zbug_erreur_compilation' => 'Erreur de compilation',
	'zbug_erreur_execution_page' => 'erreur d’exécution de la page',
	'zbug_erreur_filtre' => 'Erreur : filtre <b>« @filtre@ »</b> non défini',
	'zbug_erreur_filtre_nbarg_min' => 'Filtre @filtre@ : il manque @nb@ argument(s)',
	'zbug_erreur_meme_parent' => '{meme_parent} ne s’applique qu’aux boucles (FORUMS) ou (RUBRIQUES)',
	'zbug_erreur_squelette' => 'Erreur(s) dans le squelette',
	'zbug_hors_compilation' => 'Hors Compilation',
	'zbug_info_erreur_squelette' => 'Erreur sur le site',
	'zbug_inversion_ordre_inexistant' => 'inversion d’un ordre inexistant',
	'zbug_pagination_sans_critere' => '#PAGINATION sans critère {pagination} ou employé dans une boucle récursive',
	'zbug_parametres_inclus_incorrects' => 'Paramètre d’inclusion incorrect : @param@',
	'zbug_profile' => 'Temps de calcul : @time@',
	'zbug_resultat' => 'résultat',
	'zbug_serveur_indefini' => 'serveur SQL indéfini',
	'zbug_statistiques' => 'Statistiques des requêtes SQL classées par durée',
	'zbug_table_inconnue' => 'Table SQL « @table@ » inconnue',
	'zxml_connus_attributs' => 'attributs connus',
	'zxml_de' => 'de',
	'zxml_inconnu_attribut' => 'attribut inconnu',
	'zxml_inconnu_balise' => 'balise inconnue',
	'zxml_inconnu_entite' => 'entité inconnue',
	'zxml_inconnu_id' => 'ID inconnu',
	'zxml_mais_de' => 'mais de',
	'zxml_non_conforme' => 'n’est pas conforme au motif',
	'zxml_non_fils' => 'n’est pas un fils de',
	'zxml_nonvide_balise' => 'balise non vide',
	'zxml_obligatoire_attribut' => 'attribut obligatoire mais absent dans',
	'zxml_succession_fils_incorrecte' => 'succession des fils incorrecte',
	'zxml_survoler' => 'survoler pour voir les corrects',
	'zxml_valeur_attribut' => 'valeur de l’attribut',
	'zxml_vide_balise' => 'balise vide',
	'zxml_vu' => 'vu auparavant'
);
